==> cmsmadesimple-1.10.3-full.tar.gz: modules/CMSPrinting/lang/ext/sr_YU.php <==
<?php
$lang['friendlyname'] = 'CMSPrinting';
$lang['description'] = 'Ovaj modul Vam omogućava da na vrlo jednostavan način prilagodite sadržaj svojih stranica &scaron;tampaču.';
$lang['postinstall'] = 'Modul je uspe&scaron;no instaliran';
$lang['confirmuninstall'] = 'Da li ste sigurni da želite deinstalirati modul?';
$lang['postuninstall'] = 'Modul je uspe&scaron;no deinstaliran';
$lang['linktemplate'] = '&Scaron;ablon linka';
$lang['printtemplate'] = '&Scaron;ablon za &scaron;tampanje';
$lang['templatesaved'] = '&Scaron;ablon je sačuvan';
$lang['templatereset'] = '&Scaron;ablon je ponovo postavljen na podrazumevanu vrednost';
$lang['confirmresettemplate'] = 'Da li ste sigurni da želite &Scaron;ablon vratiti na podrazumevanu vrednost?';
$lang['reset'] = 'Vrati na podrazumevano';
$lang['save'] = 'Sačuvaj';
$lang['upgraded'] = 'je unapređen na verziju %s';
$lang['savetemplate'] = 'Sačuvaj &scaron;ablon';
$lang['savesettings'] = 'Sačuvaj pode&scaron;avanja';
$lang['template'] = '&Scaron;ablon';
$lang['notemplatecontent'] = 'Niste uneli sadržaj novog &Scaron;ablona...';
$lang['defaultlinktext'] = '&Scaron;tampaj ovu stranicu';
$lang['backbuttontext'] = 'Vrati se';
$lang['overridestylereset'] = 'CSS stil za &scaron;tampanje je vraćen na podrazumevanu vrednost';
$lang['overridestylesaved'] = 'CSS stil za &scaron;tampanje je sačuvan';
$lang['overridestyle'] = 'CSS stil samo za &scaron;tampanje';
$lang['confirmresetstyle'] = 'Da li ste sigurni da želite stil resetovati?';
$lang['stylesheet'] = 'Stil';
$lang['help_text'] = 'Promeni podrazumevani tekst linka za &scaron;tampanje/PDF';
$lang['help_popup'] = 'Postavite na &#039;true&#039; i stranica za &scaron;tampanje će se otvoriti u novom prozoru.';
$lang['help_script'] = 'Postavite na &#039;true&#039; i u na stranici JavaScript će se koristiti za automatsko prikazavanje dijaloga za &scaron;tampanje';
$lang['help_showbutton'] = 'Postavite na &#039;true&#039; da biste prikazali grafičko dugme';
$lang['help_class'] = 'Klasa za link, podrazumeva se na &#039;noprint&#039;';
$lang['help_src_img'] = 'Prikaži ovu sliku umesto podrazumevane';
$lang['help_class_img'] = 'Klasa za <img> tag ako showbutton pode&scaron;en';
$lang['help_more'] = 'Postavite dodatne opcije unutar <a> linka';
$lang['help_onlyurl'] = 'Prikazuje samo URL adresu , a ne kompletan link';
$lang['help_includetemplate'] = 'Ako se postavi na &#039;true&#039; ova opcija obraduje kompletan &scaron;ablon. a ne samo glavni sadržaj. Ovo verovatno zahteva pode&scaron;avanje na stilovima sa mediatip &#039;print&#039;.';
$lang['help'] = '<b>&Scaron;ta ovaj modul radi?</b>
<br/>
Omogućava Vam da ubacite link u stranice/&Scaron;ablone koji preusmerava korisnika na verziju trenutne stranice koja je prilagođena &scaron;tampanju.
<br/>
Molimo vodite računa da će, osim ako je upotrebljen <i>includetemplate=true</i> parametar, samo stvarni sadržaj stranice biti prikazan. 
<br/><br/>
<b>Kako se koristi?</b>
<br/>
U su&scaron;tini, instalirate modul, pristupite njegovom administracionom interfejsu i prekontroli&scaron;ete/izmenite &Scaron;ablone linka i stranice prilagođene &scaron;tampi.
<br/>
Na svojoj stranici ili u &Scaron;ablonu, ubacite ne&scaron;to slično ovome:
<pre>
{cms_module module=&#039;CMSPrinting&#039; <i>parametri</i>}
</pre>
ili prosto
<pre>
{print <i>parametri</i>}
</pre>

<br/>
';
$lang['utma'] = '156861353.1442176616.1313878285.1313878285.1313878285.1';
$lang['utmz'] = '156861353.1313878285.1.1.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/viewtopic.php';
$lang['qca'] = 'P0-258035289-1289209208569';
$lang['utmb'] = '156861353.1.10.1313878285';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.11-full.tar.gz: modules/CMSPrinting/lang/ext/sr_YU.php <==
<?php
$lang['friendlyname'] = 'CMSPrinting ';
$lang['description'] = 'Ovaj modul Vam omogućava da na vrlo jednostavan način prilagodite sadržaj svojih stranica &scaron;tampaču.';
$lang['postinstall'] = 'Modul je uspe&scaron;no instaliran';
$lang['confirmuninstall'] = 'Da li ste sigurni da želite deinstalirati modul?';
$lang['postuninstall'] = 'Modul je uspe&scaron;no deinstaliran';
$lang['linktemplate'] = '&Scaron;ablon linka';
$lang['printtemplate'] = '&Scaron;ablon za &scaron;tampanje';
$lang['templatesaved'] = '&Scaron;ablon je sačuvan';
$lang['templatereset'] = '&Scaron;ablon je ponovo postavljen na podrazumevanu vrednost';
$lang['confirmresettemplate'] = 'Da li ste sigurni da želite &Scaron;ablon vratiti na podrazumevanu vrednost?';
$lang['reset'] = 'Vrati na podrazumevano';
$lang['save'] = 'Sačuvaj';
$lang['upgraded'] = 'je unapređen na verziju %s';
$lang['savetemplate'] = 'Sačuvaj &scaron;ablon';
$lang['savesettings'] = 'Sačuvaj pode&scaron;avanja';
$lang['template'] = '&Scaron;ablon';
$lang['notemplatecontent'] = 'Niste uneli sadržaj novog &Scaron;ablona...';
$lang['defaultlinktext'] = '&Scaron;tampaj ovu stranicu';
$lang['backbuttontext'] = 'Vrati se';
$lang['overridestylereset'] = 'CSS stil za &scaron;tampanje je vraćen na podrazumevanu vrednost';
$lang['overridestylesaved'] = 'CSS stil za &scaron;tampanje je sačuvan';
$lang['overridestyle'] = 'CSS stil samo za &scaron;tampanje';
$lang['confirmresetstyle'] = 'Da li ste sigurni da želite stil resetovati?';
$lang['stylesheet'] = 'Stil';
$lang['help_text'] = 'Promeni podrazumevani tekst linka za &scaron;tampanje/PDF';
$lang['help_popup'] = 'Postavite na &#039;true&#039; i stranica za &scaron;tampanje će se otvoriti u novom prozoru.';
$lang['help_script'] = 'Postavite na &#039;true&#039; i u na stranici JavaScript će se koristiti za automatsko prikazavanje dijaloga za &scaron;tampanje';
$lang['help_showbutton'] = 'Postavite na &#039;true&#039; da biste prikazali grafičko dugme';
$lang['help_class'] = 'Klasa za link, podrazumeva se na &#039;noprint&#039;';
$lang['help_src_img'] = 'Prikaži ovu sliku umesto podrazumevane';
$lang['help_class_img'] = 'Klasa za <img> tag ako showbutton pode&scaron;en';
$lang['help_more'] = 'Postavite dodatne opcije unutar <a> linka';
$lang['help_onlyurl'] = 'Prikazuje samo URL adresu , a ne kompletan link';
$lang['help_includetemplate'] = 'Ako se postavi na &#039;true&#039; ova opcija obraduje kompletan &scaron;ablon. a ne samo glavni sadržaj. Ovo verovatno zahteva pode&scaron;avanje na stilovima sa mediatip &#039;print&#039;.';
$lang['help'] = '<b>&Scaron;ta ovaj modul radi?</b>
<br/>
Omogućava Vam da ubacite link u stranice/&Scaron;ablone koji preusmerava korisnika na verziju trenutne stranice koja je prilagođena &scaron;tampanju.
<br/>
Molimo vodite računa da će, osim ako je upotrebljen <i>includetemplate=true</i> parametar, samo stvarni sadržaj stranice biti prikazan. 
<br/><br/>
<b>Kako se koristi?</b>
<br/>
U su&scaron;tini, instalirate modul, pristupite njegovom administracionom interfejsu i prekontroli&scaron;ete/izmenite &Scaron;ablone linka i stranice prilagođene &scaron;tampi.
<br/>
Na svojoj stranici ili u &Scaron;ablonu, ubacite ne&scaron;to slično ovome:
<pre>
{cms_module module=&#039;CMSPrinting&#039; <i>parametri</i>}
</pre>
ili prosto
<pre>
{print <i>parametri</i>}
</pre>

<br/>
';
$lang['utma'] = '156861353.332286768.1323818253.1323818253.1323818253.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1323818253.1.1.utmccn=(referral)|utmcsr=cmsms.org|utmcct=/|utmcmd=referral';
?>
